@@ -1,8 +1,8 @@
 from math import inf
 
-from ...solvers import solver_instance
-from ...simulation import get_simulator
-from ...simulation.simulation import Simulator
+from mewpy.solvers import solver_instance
+from mewpy.simulation import get_simulator
+from mewpy.simulation.simulation import Simulator
 from .. import Preprocessing, ExpressionSet
 
 
