@@ -1,6 +1,5 @@
-from .problem import AbstractKOProblem, AbstractOUProblem
-from mewpy.simulation.kinetic import KineticSimulation
-from collections import OrderedDict
+from mewpy.problems.problem import AbstractKOProblem, AbstractOUProblem
+from ..simulation.kinetic import KineticSimulation
 
 
 class KineticKOProblem(AbstractKOProblem):
@@ -19,13 +18,10 @@ class KineticKOProblem(AbstractKOProblem):
         self._trg_list = list(target)
 
     def decode(self, candidate):
-        factors = OrderedDict([(self.target_list[idx], 0) for idx in candidate])
+        factors = {self.target_list[idx]: 0 for idx in candidate}
         return factors
 
     def evaluate_solution(self, solution, decode=True):
-        """
-        overrides evaluate_solution
-        """
         p = []
         factors = self.decode(solution) if decode else solution
         simulation_results = self.kinetic_sim.simulate(factors=factors)
@@ -54,9 +50,6 @@ class KineticOUProblem(AbstractOUProblem):
         return factors
 
     def evaluate_solution(self, solution, decode=True):
-        """
-        overrides evaluate_solution
-        """
         p = []
         factors = self.decode(solution) if decode else solution
         simulation_results = self.kinetic_sim.simulate(factors=factors)
