@@ -52,7 +52,9 @@ class CobraModelContainer(ModelContainer):
 
     def get_gene(self, g_id):
         g = self.model.genes.get_by_id(g_id)
-        res = {'id': g_id, 'name': g.name}
+        gr = self.get_gene_reactions()
+        r = gr[g_id]
+        res = {'id': g_id, 'name': g.name, 'reactions': r}
         return AttrDict(res)
 
     @property
@@ -457,7 +459,7 @@ class Simulation(CobraModelContainer, Simulator):
                                       )
             return result
 
-    def FVA(self, obj_frac=0.9, reactions=None, constraints=None, loopless=False, internal=None, solver=None,
+    def FVA(self, reactions=None, obj_frac=0.9, constraints=None, loopless=False, internal=None, solver=None,
             format='dict'):
         """ Flux Variability Analysis (FVA).
 
@@ -481,6 +483,15 @@ class Simulation(CobraModelContainer, Simulator):
             simul_constraints.update({k: v for k, v in constraints.items()
                                       if k not in list(self._environmental_conditions.keys())})
 
+        if reactions is None:
+            _reactions = self.reactions
+        elif isinstance(reactions,str):
+            _reactions = [reactions]
+        elif isinstance(reactions, list):
+            _reactions = reactions
+        else:
+            raise ValueError('Invalid reactions.')
+
         with self.model as model:
 
             if simul_constraints:
@@ -492,12 +503,12 @@ class Simulation(CobraModelContainer, Simulator):
                     else:
                         reac.bounds = (simul_constraints.get(
                             rxn), simul_constraints.get(rxn))
-
+            
             df = flux_variability_analysis(
-                model, reaction_list=reactions, loopless=loopless, fraction_of_optimum=obj_frac)
+                model, reaction_list=_reactions, loopless=loopless, fraction_of_optimum=obj_frac)
 
         variability = {}
-        for r_id in reactions:
+        for r_id in _reactions:
             variability[r_id] = [
                 float(df.loc[r_id][0]), float(df.loc[r_id][1])]
 
@@ -535,6 +546,7 @@ class GeckoSimulation(Simulation):
         self.protein_prefix = protein_prefix if protein_prefix else 'draw_prot_'
         self._essential_proteins = None
         self._protein_rev_reactions = None
+        self._prot_react = None
 
     @property
     def proteins(self):
@@ -553,20 +565,68 @@ class GeckoSimulation(Simulation):
             if res:
                 if (res.status == SStatus.OPTIMAL and res.objective_value < wt_growth * min_growth) or \
                         res.status == SStatus.INFEASIBLE:
-                    self._essential_proteins.append(rxn)
+                    self._essential_proteins.append(p)
         return self._essential_proteins
 
+    def map_prot_react(self):
+        if self._prot_react is None:
+            self._prot_react=dict()
+            for p in self.proteins:
+                self._prot_react[p]=[]
+            
+            for r_id in self.reactions:
+                rxn = self.model.reactions.get_by_id(r_id)
+                lsub = rxn.reactants
+                for m in lsub:
+                    if 'prot_' in m.id:
+                        p = m.id[5:-2]
+                        try:
+                            l = self._prot_react[p]
+                            l.append(r_id)
+
+                        except Exception:
+                            pass
+        return self._prot_react            
+    
     def protein_reactions(self, protein):
         """
         Returns the list of reactions associated to a protein.
         """
-        reactions = []
-        for r_id, rxn in self.model.reactions.items():
-            lsub = rxn.reactants
-            for m in lsub:
-                if protein in m:
-                    reactions.append(r_id)
-        return reactions
+        mapper = self.map_prot_react()
+        return mapper[protein]
+
+    def get_protein(self,p_id):
+        res = {'id': p_id, 'reactions': self.protein_reactions(p_id)}
+        return AttrDict(res)
+
+    def find_proteins(self, pattern=None, sort=False):
+        """A user friendly method to find proteins in the model.
+
+        :param pattern: The pattern which can be a regular expression, defaults to None in which case all entries are listed.
+        :type pattern: str, optional
+        :param sort: if the search results should be sorted, defaults to False
+        :type sort: bool, optional
+        :return: the search results
+        :rtype: pandas dataframe
+        """
+        values = self.proteins
+        if pattern:
+            import re
+            if isinstance(pattern, list):
+                patt = '|'.join(pattern)
+                re_expr = re.compile(patt)
+            else:
+                re_expr = re.compile(pattern)
+            values = [x for x in values if re_expr.search(x) is not None]
+        if sort:
+            values.sort()
+
+        import pandas as pd
+    
+        data = [self.get_protein(x) for x in values]
+        df = pd.DataFrame(data)
+        return df
+
 
     def reverse_reaction(self, reaction_id):
         """
@@ -620,8 +680,11 @@ class GeckoSimulation(Simulation):
         return self._protein_rev_reactions
 
     def getKcat(self, protein):
-        """ Returns a dictionary of reactions and respective Kcat for a specific enzyme·
+        """ Returns a dictionary of reactions and respective Kcat for a specific protein/enzyme·
         """
         m_r = self.metabolite_reaction_lookup()
-        r_d = m_r[protein]
-        return {k: v for k, v in r_d.items() if v < 0}
+        res = dict()
+        for m, k in m_r.items():
+            if protein in m:
+                res.update({r: -1/x for r, x in k.items() if x < 0})
+        return res
